# D3flux

[![Build Status](https://travis-ci.org/pstjohn/d3flux.svg?branch=master)](https://travis-ci.org/pstjohn/d3flux)
[![PyPI version](https://badge.fury.io/py/d3flux.svg)](https://badge.fury.io/py/d3flux)

This package implements a d3.js based visualization tool for cobrapy models.

![](https://cloud.githubusercontent.com/assets/2576846/23142805/09426396-f77b-11e6-9c63-028a6c16a367.png)

*Note*: This is still very much alpha software. Many things won't work :)


## Install
Install via pip:
```
pip install d3flux
```

Or, setup a development version by cloning the repo

```
git clone git@github.com:pstjohn/d3flux.git
cd d3flux
python setup.py develop
```

## Documentation
[https://pstjohn.github.io/d3flux/](https://pstjohn.github.io/d3flux/)
